pub enum IpcRequest {
Ping,
Status,
Fetch {
repo: String,
},
Push {
repo: String,
branch: String,
commit: String,
},
}Expand description
Requests sent from the CLI tool to the Daemon via the local IPC pipe.
Variants
Ping
Ping the daemon to check connectivity.
Status
Request the current status of the daemon.
Fetch
Instruct the daemon to fetch updates for a specific repository.
Push
Instruct the daemon to announce a new push for a repository.